==> mc-4.5.52.tar.gz: mc-4.5.52/lib/mc.hint.pl <==
Midnight Commander (c) 1995-1997, Free Software Foundation
Porada: Za pomoc C-x t kopiuje si nazwy zaznaczoych plikw do wiersza polece.
Porada: Za pomoc C-x p kopiuje si nazw biecej cieki do wiersza polece.
Porada: Uzupenianie: M-Tab (lub Esc+Tab). Podwjne wcinicie wywouje list.
Porada: M-p i M-n udostpnia histori polece.
Porada: Cytowanie znaku mona uzyska naciskajc Contrl-q i odpowiedni znak.
Porada: Zmczony poradami? Wycz je w menu Opcje|Ukad...
Porada: Wybieranie katalogw: dodaj ukonik na kocu wzorca dopasowania.
Porada: Jeli w twoim terminalu brak klawiszy funkcyjnych, uyj Esc+numer.
Porada: Witryna Midnight Commandera jest pod adresem http://www.gnome.org/mc/
Porada: Najnowsza wersja MC pod adresem ftp://ftp.gnome.org/pub/GNOME/sources/mc
Porada: Opis bdw (w jzyku angielskim) wysyaj na mc-bugs@nuclecu.unam.mx
Porada: Strona domowa Midnight Commandera pod adresem http://www.gnome.org/mc
Porada: Za pomoc klawisza Tab zmienia si biecy panel.
Porada: VFS: nacinij Enter na archiwum tar, aby obejrze jego zawarto.
Porada: Na stron podrcznikow te warto zajrze.
Porada: Chcesz si porusza tak jak w lynksie? Ustaw to w menu Konfiguracja...
Porada: Makra % dziaaj nawet w wierszu polece.
Porada: M-! pozwala na podgld wyjcia uruchamianych programw w przegldarce.
Porada: Tryb wywietlania listy plikw mona dostosowywa: zobacz "man mc".
Porada: %D/%T oznacza zazanaczone pliki w drugim panelu.
Porada: Dostp do zwykej powoki przez C-o. Powrt do MC przez ponowne C-o.
Porada: Ustawienie zmiennej CDPATH moe ci zaoszczdzi pisania.
Porada: Jeli chcesz zobaczy pliki .*, zmie ustawienie w menu Konfiguracja...
Porada: Jeli chcesz zobaczy pliki .*~, zmie ustawienie w menu Konfiguracja...
Porada: Masz duo pamici? Ustaw limit pamici VFS archiwum tar na -1.
Porada: Uzupenianie dziaa wszdzie. Po prostu nacinij M-Tab.
Porada: Jeli masz powolny terminal, sprbuj uy opcji -s.
Porada: Znajd plik: na znalezionych plikach wykonujemy operacje poprzez Filtruj.
Porada: Chcesz uy zoonego wyszukiwania? Uyj polecenia Filtr zewntrzny.
Porada: Jeli chcesz szybciej zmienia ciek, uyj M-c (szybka zmiana katalogu).
Porada: Polecenia powoki dziaaj tylko w lokalnym systemie plikw.
Porada: Przywr skasowany tekst za pomoc C-y.
Porada: Niektre klawisze nie dziaaj? Patrz menu Opcje|Definiuj klawisze...
Porada: Aby obejrze wyjcie polecenia w przegldarce uyj M-!
Porada: F13 (lub Shift-F3) wywouje przegldark w trybie surowym.
Porada: Nie dziaaj klawisze w xterm? Uyj naszych plikw xterm.ad, .ti i .tcap
Porada: Moesz okreli edytor pod F4 przez zmienn powoki EDITOR.
Porada: Moesz okreli zewntrzn przegldark przez zmienn powoki PAGER.
Porada: Moesz wyczy dania potwierdzenia przez menu Opcje|Potwierdzanie...
Porada: Przejd do listy najczciej uywanych katalogw przez C-\.
Porada: Z anonimowego FTP korzystamy piszc 'cd /#ftp:machine.edu'
Porada: MC ma wbudowan obsug FTP; patrz menu Plik, Poczenie FTP...
Porada: M-t przecza tryby wywietlania listy plikw.
Porada: Uytkownika FTP okrelamy przez: 'cd /#ftp:user@machine.edu'
Porada: Pakiety RPM przegldamy naciskajc na nich Enter.
Porada: Aby zazanaczy katalogi w oknie dialogowym zaznaczania dodaj ukonik.
Porada: Uywanie kopiowania i wklejania za pomoc myszy moe wymaga Shifta.
Porada: Klawiszem C-\ dopisz do podrcznej listy czsto odwiedzane zasoby FTP.

==> mc-4.6.0-pre1.tar.gz: mc-4.6.0-pre1/lib/mc.hint.pl <==
Midnight Commander (c) 1995-2001, Free Software Foundation
Porada: Za pomoc C-x t kopiuje si nazwy zaznaczoych plikw do wiersza polece.
Porada: Za pomoc C-x p kopiuje si nazw biecej cieki do wiersza polece.
Porada: Uzupenianie: M-Tab (lub Esc+Tab). Podwjne wcinicie wywouje list.
Porada: M-p i M-n udostpnia histori polece.
Porada: Cytowanie znaku mona uzyska naciskajc Contrl-q i odpowiedni znak.
Porada: Zmczony poradami? Wycz je w menu Opcje|Ukad...
Porada: Wybieranie katalogw: dodaj ukonik na kocu wzorca dopasowania.
Porada: Jeli w twoim terminalu brak klawiszy funkcyjnych, uyj Esc+numer.
Porada: Witryna Midnight Commandera jest pod adresem http://www.gnome.org/mc/
Porada: Opis bdw (w jzyku angielskim) wysyaj na mc-devel@gnome.org
Porada: Strona domowa Midnight Commandera pod adresem http://www.gnome.org/mc
Porada: Za pomoc klawisza Tab zmienia si biecy panel.
Porada: VFS: nacinij Enter na archiwum tar, aby obejrze jego zawarto.
Porada: Na stron podrcznikow te warto zajrze.
Porada: Chcesz si porusza tak jak w lynksie? Ustaw to w menu Konfiguracja...
Porada: Makra % dziaaj nawet w wierszu polece.
Porada: M-! pozwala na podgld wyjcia uruchamianych programw w przegldarce.
Porada: Tryb wywietlania listy plikw mona dostosowywa: zobacz "man mc".
Porada: %D/%T oznacza zazanaczone pliki w drugim panelu.
Porada: Dostp do zwykej powoki przez C-o. Powrt do MC przez ponowne C-o.
Porada: Ustawienie zmiennej CDPATH moe ci zaoszczdzi pisania.
Porada: Jeli chcesz zobaczy pliki .*, zmie ustawienie w menu Konfiguracja...
Porada: Jeli chcesz zobaczy pliki .*~, zmie ustawienie w menu Konfiguracja...
Porada: Masz duo pamici? Ustaw limit pamici VFS archiwum tar na -1.
Porada: Uzupenianie dziaa wszdzie. Po prostu nacinij M-Tab.
Porada: Jeli masz powolny terminal, sprbuj uy opcji -s.
Porada: Znajd plik: na znalezionych plikach wykonujemy operacje poprzez Filtruj.
Porada: Chcesz uy zoonego wyszukiwania? Uyj polecenia Filtr zewntrzny.
Porada: Jeli chcesz szybciej zmienia ciek, uyj M-c (szybka zmiana katalogu).
Porada: Polecenia powoki dziaaj tylko w lokalnym systemie plikw.
Porada: Przywr skasowany tekst za pomoc C-y.
Porada: Niektre klawisze nie dziaaj? Patrz menu Opcje|Definiuj klawisze...
Porada: Aby obejrze wyjcie polecenia w przegldarce uyj M-!
Porada: F13 (lub Shift-F3) wywouje przegldark w trybie surowym.
Porada: Nie dziaaj klawisze w xterm? Uyj naszych plikw xterm.ad, .ti i .tcap
Porada: Moesz okreli edytor pod F4 przez zmienn powoki EDITOR.
Porada: Moesz okreli zewntrzn przegldark przez zmienn powoki PAGER.
Porada: Moesz wyczy dania potwierdzenia przez menu Opcje|Potwierdzanie...
Porada: Przejd do listy najczciej uywanych katalogw przez C-\.
Porada: Z anonimowego FTP korzystamy piszc 'cd /#ftp:machine.edu'
Porada: MC ma wbudowan obsug FTP; patrz menu Plik, Poczenie FTP...
Porada: M-t przecza tryby wywietlania listy plikw.
Porada: Uytkownika FTP okrelamy przez: 'cd /#ftp:user@machine.edu'
Porada: Pakiety RPM przegldamy naciskajc na nich Enter.
Porada: Aby zazanaczy katalogi w oknie dialogowym zaznaczania dodaj ukonik.
Porada: Uywanie kopiowania i wklejania za pomoc myszy moe wymaga Shifta.
Porada: Klawiszem C-\ dopisz do podrcznej listy czsto odwiedzane zasoby FTP.
